# run_tests_report.html

Report generated on 11-Nov-2022 at 12:27:57 by pytest-html v3.2.0

## Environment

JAVA_HOME | /Library/Java/JavaVirtualMachines/adoptopenjdk-8.jdk/Contents/Home
Packages | {"pluggy": "1.0.0", "pytest": "7.2.0"}
Platform | macOS-10.16-x86_64-i386-64bit
Plugins | {"html": "3.2.0", "metadata": "2.0.4"}
Python | 3.10.6

## Summary

4 tests ran in 13.42 seconds.

(Un)check the boxes to filter the results.

4 passed, 0 skipped, 0 failed, 0 errors, 0 expected failures, 0 unexpected passes

## Results

Result | Test | Duration | Links
--- | --- | --- | ---
No results found. Try to check the filters
Passed | tests/open_source/test_runs.py::test_run_basic | 4.00 |
No log output captured.
Passed | tests/open_source/test_runs.py::test_run_with_source_tags | 1.71 |
No log output captured.
Passed | tests/open_source/test_runs.py::test_run_basic_use_metric_steps | 2.33 |
No log output captured.
Passed | tests/open_source/test_runs.py::test_model_predictions | 1.65 |
No log output captured.